import { BeetExports, BeetTypeMapKey, SupportedTypeDefinition } from '@metaplex-foundation/beet';
import { BeetSolanaExports, BeetSolanaTypeMapKey } from '@metaplex-foundation/beet-solana';
import { SerdePackage } from './serdes';
export declare type TypeAliases = Record<string, PrimitiveTypeKey>;
/**
 * Key: account name for which to customize de/serializer
 * Value: path to module from project root providing `serialize` and/or
 *        `deserialize` methods
 */
export declare type Serializers = Record<string, string>;
export declare type IdlField = {
    name: string;
    type: IdlType;
    attrs?: string[];
};
export declare const IDL_FIELD_ATTR_PADDING = "padding";
export declare type IdlInstructionAccount = {
    name: string;
    isMut: boolean;
    isSigner: boolean;
    desc?: string;
    optional?: boolean;
};
export declare type IdlType = BeetTypeMapKey | 'publicKey' | IdlTypeDefined | IdlTypeOption | IdlTypeVec | IdlTypeArray | IdlTypeEnum | IdlTypeDataEnum;
export declare type IdlTypeDefined = {
    defined: string;
};
export declare type IdlTypeOption = {
    option: IdlType;
};
export declare type IdlTypeVec = {
    vec: IdlType;
};
export declare type IdlTypeArray = {
    array: [idlType: IdlType, size: number];
};
export declare type IdlEnumVariant = {
    name: string;
};
export declare type IdlDataEnumVariant = {
    name: string;
    fields: IdlField[];
};
export declare type IdlTypeEnum = IdlTypeScalarEnum | IdlTypeDataEnum;
export declare type IdlTypeScalarEnum = {
    kind: 'enum';
    variants: IdlEnumVariant[];
};
export declare type IdlTypeDataEnum = {
    kind: 'enum';
    variants: IdlDataEnumVariant[];
};
export declare type IdlDefinedType = {
    kind: 'struct' | 'enum';
    fields: IdlField[];
};
export declare type IdlDefinedTypeDefinition = {
    name: string;
    type: IdlDefinedType | IdlTypeEnum | IdlTypeDataEnum;
};
export declare type IdlInstructionArg = {
    name: string;
    type: IdlType;
};
export declare type IdlInstruction = {
    name: string;
    accounts: IdlInstructionAccount[];
    args: IdlInstructionArg[];
};
export declare type IdlAccountType = {
    kind: 'struct' | 'enum';
    fields: IdlField[];
};
export declare type IdlAccount = {
    name: string;
    type: IdlAccountType;
};
export declare type IdlError = {
    code: number;
    name: string;
    msg?: string;
};
export declare type Idl = {
    version: string;
    name: string;
    instructions: IdlInstruction[];
    accounts?: IdlAccount[];
    errors?: IdlError[];
    types?: IdlDefinedTypeDefinition[];
    metadata: {
        address: string;
    };
};
export declare type ShankIdl = Idl & {
    instructions: ShankIdlInstruction[];
    metadata: ShankMetadata;
};
export declare type ShankIdlInstruction = IdlInstruction & {
    accounts: IdlInstructionAccountWithDesc[];
    discriminant: {
        type: IdlType;
        value: number;
    };
};
export declare type IdlInstructionAccountWithDesc = IdlInstructionAccount & {
    desc: string;
};
export declare type ShankMetadata = Idl['metadata'] & {
    origin: 'shank';
};
export declare type PrimitiveTypeKey = BeetTypeMapKey | BeetSolanaTypeMapKey;
export declare type PrimaryTypeMap = Record<PrimitiveTypeKey, SupportedTypeDefinition & {
    beet: BeetExports | BeetSolanaExports;
}>;
export declare type ProcessedSerde = {
    name: string;
    sourcePack: SerdePackage;
    type: string;
    inner?: ProcessedSerde;
};
export declare type TypeMappedSerdeField = {
    name: string;
    type: string;
};
export declare type ResolveFieldType = (typeName: string) => IdlAccountType | IdlTypeEnum | null;
export declare function isIdlTypeOption(ty: IdlType): ty is IdlTypeOption;
export declare function isIdlTypeVec(ty: IdlType): ty is IdlTypeVec;
export declare function isIdlTypeArray(ty: IdlType): ty is IdlTypeArray;
export declare function asIdlTypeArray(ty: IdlType): IdlTypeArray;
export declare function isIdlTypeDefined(ty: IdlType): ty is IdlTypeDefined;
export declare function isIdlTypeEnum(ty: IdlType | IdlDefinedType | IdlTypeEnum): ty is IdlTypeEnum;
export declare function isIdlTypeDataEnum(ty: IdlType | IdlDefinedType | IdlTypeEnum): ty is IdlTypeDataEnum;
export declare function isIdlTypeScalarEnum(ty: IdlType | IdlDefinedType | IdlTypeEnum): ty is IdlTypeScalarEnum;
export declare function isIdlDefinedType(ty: IdlType | IdlDefinedType): ty is IdlDefinedType;
export declare function isShankIdl(ty: Idl): ty is ShankIdl;
export declare function isShankIdlInstruction(ty: IdlInstruction): ty is ShankIdlInstruction;
export declare function isIdlInstructionAccountWithDesc(ty: IdlInstructionAccount): ty is IdlInstructionAccountWithDesc;
export declare function hasPaddingAttr(field: IdlField): boolean;
export declare const BEET_PACKAGE = "@metaplex-foundation/beet";
export declare const BEET_SOLANA_PACKAGE = "@metaplex-foundation/beet-solana";
export declare const SOLANA_WEB3_PACKAGE = "@solana/web3.js";
export declare const SOLANA_SPL_TOKEN_PACKAGE = "@solana/spl-token";
export declare const BEET_EXPORT_NAME = "beet";
export declare const BEET_SOLANA_EXPORT_NAME = "beetSolana";
export declare const SOLANA_WEB3_EXPORT_NAME = "web3";
export declare const SOLANA_SPL_TOKEN_EXPORT_NAME = "splToken";
export declare const PROGRAM_ID_PACKAGE = "<program-id>";
export declare const PROGRAM_ID_EXPORT_NAME = "<program-id-export>";
